@@ -20,27 +20,20 @@
 #define CORE_MUTEX_H
 
 #include "config/config.h"
-#include "core/semaphore.h"
+#include "core/thread.h"
+#include "core/task.h"
 
-struct mutex {
-	semaphore_t semaphore;
-#if CONFIG_MUTEX_DEBUG
-#endif
+class mutex {
+ public:
+        mutex();
+        ~mutex();
+
+        void lock();
+        void unlock();
+
+ private:
+        task *   owner_task;
+        thread * owner_thread;
 };
-typedef struct mutex mutex_t;
-
-
-/* Statically allocated mutexes */
-int      mutex_init(mutex_t * mutex);
-int      mutex_fini(mutex_t * mutex);
-
-/* Dinamically allocated mutexes */
-mutex_t* mutex_new(void);
-void     mutex_delete(mutex_t * mutex);
-
-void     mutex_lock(mutex_t * mutex);
-int      mutex_locked(mutex_t * mutex);
-void     mutex_unlock(mutex_t * mutex);
-int      mutex_trylock(mutex_t * mutex);
 
 #endif // CORE_MUTEX_H
